==> mrpt_0.9.4.orig.tar.gz: mrpt-0.9.4/libs/base/src/utils/mrpt_font_6x13B.h <==
/* +---------------------------------------------------------------------------+
   |          The Mobile Robot Programming Toolkit (MRPT) C++ library          |
   |                                                                           |
   |                   http://mrpt.sourceforge.net/                            |
   |                                                                           |
   |   Copyright (C) 2005-2011  University of Malaga                           |
   |                                                                           |
   |    This software was written by the Machine Perception and Intelligent    |
   |      Robotics Lab, University of Malaga (Spain).                          |
   |    Contact: Jose-Luis Blanco  <jlblanco@ctima.uma.es>                     |
   |                                                                           |
   |  This file is part of the MRPT project.                                   |
   |                                                                           |
   |     MRPT is free software: you can redistribute it and/or modify          |
   |     it under the terms of the GNU General Public License as published by  |
   |     the Free Software Foundation, either version 3 of the License, or     |
   |     (at your option) any later version.                                   |
   |                                                                           |
   |   MRPT is distributed in the hope that it will be useful,                 |
   |     but WITHOUT ANY WARRANTY; without even the implied warranty of        |
   |     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         |
   |     GNU General Public License for more details.                          |
   |                                                                           |
   |     You should have received a copy of the GNU General Public License     |
   |     along with MRPT.  If not, see <http://www.gnu.org/licenses/>.         |
   |                                                                           |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_6x13B [] = {
31,139,8,0,0,0,0,0,4,3,237,154,219,110,37,69,
12,69,131,16,3,136,155,64,48,2,2,156,121,26,144,72,
184,136,171,148,112,248,255,175,2,175,73,47,216,199,84,119,
87,52,72,60,208,150,28,187,170,188,125,171,234,234,78,102,
158,92,93,93,189,83,12,253,241,32,174,62,42,9,67,239,
47,220,245,180,97,237,160,163,3,71,7,142,14,28,29,56,
58,240,95,117,224,237,10,188,198,228,196,90,167,235,154,144,
251,218,214,248,139,90,132,127,111,146,185,53,34,62,235,239,
45,242,126,145,163,188,106,233,234,231,98,253,127,92,58,118,
79,138,141,75,222,107,132,29,113,96,116,252,96,127,46,238,
132,95,185,175,141,198,230,98,62,248,79,214,23,118,18,235,
57,207,90,178,107,216,141,232,135,154,180,110,36,227,61,210,
39,181,171,239,97,70,235,159,45,248,181,220,196,16,231,101,
136,28,169,13,153,244,93,13,96,251,197,186,253,126,181,116,
184,147,190,232,83,231,81,12,240,96,222,45,230,204,160,119,
30,213,231,94,16,195,28,193,145,31,121,141,48,204,165,45,
62,172,17,63,140,59,89,59,123,193,250,167,197,156,103,124,
185,86,234,5,177,102,127,78,165,255,82,188,23,7,255,230,
14,86,156,61,28,229,70,28,235,33,23,251,230,30,33,59,
225,71,159,214,220,199,91,152,187,90,60,23,91,15,113,217,
187,17,145,15,241,144,210,104,206,53,229,200,102,237,89,176,
126,48,246,15,201,152,220,88,223,34,122,40,165,238,156,146,
61,233,126,237,185,113,181,85,102,175,51,79,114,131,148,15,
163,135,159,137,161,215,228,4,159,138,201,129,222,119,194,79,
226,216,79,48,185,175,29,131,63,238,121,25,188,58,146,245,
78,198,240,108,167,244,44,117,76,143,147,49,214,226,144,123,
250,198,71,142,89,239,180,135,1,223,105,84,15,61,183,111,
172,119,114,77,73,92,117,101,199,224,135,61,90,227,81,156,
251,178,247,25,235,146,56,35,140,241,185,159,184,75,95,95,
36,99,215,74,189,160,236,235,72,31,245,90,95,172,201,206,
41,47,130,212,128,121,238,65,88,12,189,206,126,215,240,130,
168,81,127,35,57,234,193,169,97,24,247,186,46,130,212,96,
43,14,185,178,222,239,145,81,28,122,190,213,107,227,152,143,
126,241,77,125,140,59,17,127,237,220,56,223,49,163,94,229,
220,40,78,174,155,11,118,240,108,28,114,77,198,79,39,227,
164,111,117,215,102,48,230,164,236,24,242,160,175,220,209,121,
79,123,87,179,158,68,14,172,237,49,118,73,238,165,56,242,
49,166,207,109,218,131,119,125,75,246,56,248,101,110,212,211,
244,255,88,61,251,64,13,196,121,25,34,71,234,62,23,147,
43,207,55,247,124,39,251,134,228,153,225,94,112,255,209,153,
219,34,123,161,31,176,204,117,114,15,144,228,65,62,198,89,
203,45,125,24,135,62,25,107,20,135,239,19,252,123,14,78,
161,59,87,83,171,116,174,21,106,134,249,158,34,150,177,51,
158,57,32,177,205,190,89,87,77,95,80,62,35,248,118,172,
76,255,2,61,155,140,169,205,177,50,115,21,211,115,27,189,
131,180,85,142,242,49,47,228,40,55,177,72,250,204,222,36,
211,135,45,154,237,91,250,112,47,236,49,114,47,183,140,227,
153,206,30,165,127,245,60,163,119,53,201,56,207,176,118,41,
141,147,190,209,183,200,122,232,63,123,186,85,143,231,183,159,
105,114,227,108,108,81,246,11,221,154,102,49,228,9,115,22,
182,200,56,121,14,62,216,2,212,154,53,123,222,236,201,22,
204,56,89,11,251,163,175,17,150,156,232,49,113,232,37,123,
195,92,18,125,180,207,72,108,249,126,19,227,90,239,183,185,
111,201,114,243,23,233,83,123,252,26,219,57,36,118,73,79,
107,192,254,191,153,147,135,126,116,224,232,192,209,129,163,3,
71,7,254,167,29,240,157,73,249,234,35,217,219,243,70,77,
240,189,241,117,241,91,11,163,51,199,218,136,120,79,243,205,
229,183,0,239,99,245,231,165,51,94,35,190,79,248,230,224,
155,8,70,103,110,68,204,251,61,67,62,216,82,147,18,61,
169,215,235,218,218,60,235,126,107,241,45,164,110,204,173,239,
41,115,51,198,140,212,255,109,25,243,29,254,229,34,25,27,
179,212,11,58,213,136,60,168,249,251,69,150,120,49,70,174,
209,77,45,240,173,196,158,190,182,72,198,204,239,17,177,224,
103,11,151,152,34,234,219,35,123,240,91,25,254,84,140,164,
126,244,173,30,208,135,199,144,113,214,124,142,124,121,78,172,
223,49,182,206,37,142,111,83,254,239,16,118,156,127,206,16,
191,107,110,145,24,236,193,129,239,223,184,29,175,255,62,255,
152,177,231,53,37,53,189,178,176,190,206,165,48,255,109,240,
55,165,223,4,151,186,74,228,10,255,27,148,117,211,47,250,
132,148,247,122,205,239,148,167,98,254,15,23,146,49,132,190,
71,236,11,255,198,246,99,241,87,139,100,204,124,167,158,219,
243,50,160,135,191,22,211,183,251,98,158,225,164,142,225,188,
114,39,96,231,239,104,224,146,250,217,185,173,69,48,91,113,
114,63,212,137,205,89,245,44,16,59,137,117,108,33,100,62,
75,212,37,142,117,201,156,25,207,98,124,143,60,6,115,83,
198,236,3,52,27,39,243,157,197,96,199,251,137,218,103,49,
101,250,226,239,141,156,17,249,243,210,57,167,48,115,220,119,
157,236,47,123,210,153,220,205,129,125,129,114,127,216,15,49,
156,107,117,230,147,114,127,102,49,185,63,179,152,236,245,44,
38,235,177,86,122,158,204,124,82,214,51,139,225,249,231,111,
84,208,44,38,235,153,197,224,255,84,204,55,146,204,115,170,
142,100,61,233,166,6,158,107,98,98,15,211,67,254,86,5,
51,159,212,251,102,174,41,247,250,150,182,234,29,147,231,128,
53,237,82,118,76,214,51,139,209,31,53,206,98,178,31,232,
248,0,203,217,209,71,169,67,122,86,179,216,100,127,237,59,
243,188,27,165,236,181,121,118,9,38,41,207,104,183,117,220,
49,217,107,109,186,236,24,207,21,177,187,173,227,142,233,185,
229,93,151,207,93,214,131,206,253,194,217,213,47,146,177,247,
14,114,68,196,23,51,194,103,175,193,103,191,193,242,94,60,
23,227,131,253,162,230,78,89,211,44,38,251,61,139,233,103,
123,38,183,220,163,153,56,228,245,97,49,18,154,193,60,88,
254,253,19,12,185,34,121,247,220,22,63,45,222,34,108,233,
177,251,137,206,28,103,130,61,145,250,254,96,199,93,37,14,
76,167,190,63,51,152,190,63,51,152,222,235,25,76,214,195,
123,34,159,1,244,189,122,102,49,249,14,154,197,92,87,124,
24,154,193,96,139,29,223,28,159,20,187,167,244,65,30,213,
195,89,241,29,132,15,238,66,237,149,53,117,65,217,183,217,
56,163,115,160,127,228,40,183,209,57,216,195,100,61,179,185,
233,147,34,103,49,216,122,94,208,121,14,160,156,123,152,185,
252,249,172,134,198,184,43,157,216,246,156,249,173,59,209,60,
149,224,247,238,68,109,149,107,152,236,181,182,202,53,140,235,
149,198,63,206,204,26,38,207,129,120,164,246,220,171,140,233,
69,146,119,204,117,77,218,47,36,99,215,144,146,190,25,171,
239,197,249,19,168,42,53,120,24,52,0,0,};

==> mrpt_1.0.0.orig.tar.gz: mrpt-1.0.0/libs/base/src/utils/mrpt_font_6x13B.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_6x13B [] = {
31,139,8,0,0,0,0,0,4,3,237,154,219,110,37,69,
12,69,131,16,3,136,155,64,48,2,2,156,121,26,144,72,
184,136,171,148,112,248,255,175,2,175,73,47,216,199,84,119,
87,52,72,60,208,150,28,187,170,188,125,171,234,234,78,102,
158,92,93,93,189,83,12,253,241,32,174,62,42,9,67,239,
47,220,245,180,97,237,160,163,3,71,7,142,14,28,29,56,
58,240,95,117,224,237,10,188,198,228,196,90,167,235,154,144,
251,218,214,248,139,90,132,127,111,146,185,53,34,62,235,239,
45,242,126,145,163,188,106,233,234,231,98,253,127,92,58,118,
79,138,141,75,222,107,132,29,113,96,116,252,96,127,46,238,
132,95,185,175,141,198,230,98,62,248,79,214,23,118,18,235,
57,207,90,178,107,216,141,232,135,154,180,110,36,227,61,210,
39,181,171,239,97,70,235,159,45,248,181,220,196,16,231,101,
136,28,169,13,153,244,93,13,96,251,197,186,253,126,181,116,
184,147,190,232,83,231,81,12,240,96,222,45,230,204,160,119,
30,213,231,94,16,195,28,193,145,31,121,141,48,204,165,45,
62,172,17,63,140,59,89,59,123,193,250,167,197,156,103,124,
185,86,234,5,177,102,127,78,165,255,82,188,23,7,255,230,
14,86,156,61,28,229,70,28,235,33,23,251,230,30,33,59,
225,71,159,214,220,199,91,152,187,90,60,23,91,15,113,217,
187,17,145,15,241,144,210,104,206,53,229,200,102,237,89,176,
126,48,246,15,201,152,220,88,223,34,122,40,165,238,156,146,
61,233,126,237,185,113,181,85,102,175,51,79,114,131,148,15,
163,135,159,137,161,215,228,4,159,138,201,129,222,119,194,79,
226,216,79,48,185,175,29,131,63,238,121,25,188,58,146,245,
78,198,240,108,167,244,44,117,76,143,147,49,214,226,144,123,
250,198,71,142,89,239,180,135,1,223,105,84,15,61,183,111,
172,119,114,77,73,92,117,101,199,224,135,61,90,227,81,156,
251,178,247,25,235,146,56,35,140,241,185,159,184,75,95,95,
36,99,215,74,189,160,236,235,72,31,245,90,95,172,201,206,
41,47,130,212,128,121,238,65,88,12,189,206,126,215,240,130,
168,81,127,35,57,234,193,169,97,24,247,186,46,130,212,96,
43,14,185,178,222,239,145,81,28,122,190,213,107,227,152,143,
126,241,77,125,140,59,17,127,237,220,56,223,49,163,94,229,
220,40,78,174,155,11,118,240,108,28,114,77,198,79,39,227,
164,111,117,215,102,48,230,164,236,24,242,160,175,220,209,121,
79,123,87,179,158,68,14,172,237,49,118,73,238,165,56,242,
49,166,207,109,218,131,119,125,75,246,56,248,101,110,212,211,
244,255,88,61,251,64,13,196,121,25,34,71,234,62,23,147,
43,207,55,247,124,39,251,134,228,153,225,94,112,255,209,153,
219,34,123,161,31,176,204,117,114,15,144,228,65,62,198,89,
203,45,125,24,135,62,25,107,20,135,239,19,252,123,14,78,
161,59,87,83,171,116,174,21,106,134,249,158,34,150,177,51,
158,57,32,177,205,190,89,87,77,95,80,62,35,248,118,172,
76,255,2,61,155,140,169,205,177,50,115,21,211,115,27,189,
131,180,85,142,242,49,47,228,40,55,177,72,250,204,222,36,
211,135,45,154,237,91,250,112,47,236,49,114,47,183,140,227,
153,206,30,165,127,245,60,163,119,53,201,56,207,176,118,41,
141,147,190,209,183,200,122,232,63,123,186,85,143,231,183,159,
105,114,227,108,108,81,246,11,221,154,102,49,228,9,115,22,
182,200,56,121,14,62,216,2,212,154,53,123,222,236,201,22,
204,56,89,11,251,163,175,17,150,156,232,49,113,232,37,123,
195,92,18,125,180,207,72,108,249,126,19,227,90,239,183,185,
111,201,114,243,23,233,83,123,252,26,219,57,36,118,73,79,
107,192,254,191,153,147,135,126,116,224,232,192,209,129,163,3,
71,7,254,167,29,240,157,73,249,234,35,217,219,243,70,77,
240,189,241,117,241,91,11,163,51,199,218,136,120,79,243,205,
229,183,0,239,99,245,231,165,51,94,35,190,79,248,230,224,
155,8,70,103,110,68,204,251,61,67,62,216,82,147,18,61,
169,215,235,218,218,60,235,126,107,241,45,164,110,204,173,239,
41,115,51,198,140,212,255,109,25,243,29,254,229,34,25,27,
179,212,11,58,213,136,60,168,249,251,69,150,120,49,70,174,
209,77,45,240,173,196,158,190,182,72,198,204,239,17,177,224,
103,11,151,152,34,234,219,35,123,240,91,25,254,84,140,164,
126,244,173,30,208,135,199,144,113,214,124,142,124,121,78,172,
223,49,182,206,37,142,111,83,254,239,16,118,156,127,206,16,
191,107,110,145,24,236,193,129,239,223,184,29,175,255,62,255,
152,177,231,53,37,53,189,178,176,190,206,165,48,255,109,240,
55,165,223,4,151,186,74,228,10,255,27,148,117,211,47,250,
132,148,247,122,205,239,148,167,98,254,15,23,146,49,132,190,
71,236,11,255,198,246,99,241,87,139,100,204,124,167,158,219,
243,50,160,135,191,22,211,183,251,98,158,225,164,142,225,188,
114,39,96,231,239,104,224,146,250,217,185,173,69,48,91,113,
114,63,212,137,205,89,245,44,16,59,137,117,108,33,100,62,
75,212,37,142,117,201,156,25,207,98,124,143,60,6,115,83,
198,236,3,52,27,39,243,157,197,96,199,251,137,218,103,49,
101,250,226,239,141,156,17,249,243,210,57,167,48,115,220,119,
157,236,47,123,210,153,220,205,129,125,129,114,127,216,15,49,
156,107,117,230,147,114,127,102,49,185,63,179,152,236,245,44,
38,235,177,86,122,158,204,124,82,214,51,139,225,249,231,111,
84,208,44,38,235,153,197,224,255,84,204,55,146,204,115,170,
142,100,61,233,166,6,158,107,98,98,15,211,67,254,86,5,
51,159,212,251,102,174,41,247,250,150,182,234,29,147,231,128,
53,237,82,118,76,214,51,139,209,31,53,206,98,178,31,232,
248,0,203,217,209,71,169,67,122,86,179,216,100,127,237,59,
243,188,27,165,236,181,121,118,9,38,41,207,104,183,117,220,
49,217,107,109,186,236,24,207,21,177,187,173,227,142,233,185,
229,93,151,207,93,214,131,206,253,194,217,213,47,146,177,247,
14,114,68,196,23,51,194,103,175,193,103,191,193,242,94,60,
23,227,131,253,162,230,78,89,211,44,38,251,61,139,233,103,
123,38,183,220,163,153,56,228,245,97,49,18,154,193,60,88,
254,253,19,12,185,34,121,247,220,22,63,45,222,34,108,233,
177,251,137,206,28,103,130,61,145,250,254,96,199,93,37,14,
76,167,190,63,51,152,190,63,51,152,222,235,25,76,214,195,
123,34,159,1,244,189,122,102,49,249,14,154,197,92,87,124,
24,154,193,96,139,29,223,28,159,20,187,167,244,65,30,213,
195,89,241,29,132,15,238,66,237,149,53,117,65,217,183,217,
56,163,115,160,127,228,40,183,209,57,216,195,100,61,179,185,
233,147,34,103,49,216,122,94,208,121,14,160,156,123,152,185,
252,249,172,134,198,184,43,157,216,246,156,249,173,59,209,60,
149,224,247,238,68,109,149,107,152,236,181,182,202,53,140,235,
149,198,63,206,204,26,38,207,129,120,164,246,220,171,140,233,
69,146,119,204,117,77,218,47,36,99,215,144,146,190,25,171,
239,197,249,19,168,42,53,120,24,52,0,0,};
